@@ -1,9 +1,6 @@
-# $Id: Negotiate.pm,v 1.13 2003/10/23 19:11:32 uid39246 Exp $
-#
-
 package HTTP::Negotiate;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
+$VERSION = "5.810";
 sub Version { $VERSION; }
 
 require 5.002;
@@ -191,11 +188,11 @@ sub choose ($;$)
 		$DEBUG and print " -- No exact language match\n";
 		my $selected = undef;
 		for $al (keys %{ $accept{'language'} }) {
-		    if (substr($lang, 0, 1 + length($al)) eq "$al-") {
+		    if (index($al, "$lang-") == 0) {
 		        # $lang starting with $al isn't enough, or else
 		        #  Accept-Language: hu (Hungarian) would seem
 		        #  to accept a document in hup (Hupa)
-		        $DEBUG and print " -- $lang ISA $al\n";
+		        $DEBUG and print " -- $al ISA $lang\n";
 			$selected = $al unless defined $selected;
 			$selected = $al if length($al) > length($selected);
 		    }
@@ -309,11 +306,11 @@ __END__
 
 =head1 NAME
 
-choose - choose a variant of a document to serve (HTTP content negotiation)
+HTTP::Negotiate - choose a variant to serve
 
 =head1 SYNOPSIS
 
- use HTTP::Negotiate;
+ use HTTP::Negotiate qw(choose);
 
  #  ID       QS     Content-Type   Encoding Char-Set        Lang   Size
  $variants =
@@ -464,7 +461,7 @@ F<draft-ietf-http-v11-spec-00.ps>):
 =item Accept
 
 This header can be used to indicate a list of media ranges which are
-acceptable as a reponse to the request.  The "*" character is used to
+acceptable as a response to the request.  The "*" character is used to
 group media types into ranges, with "*/*" indicating all media types
 and "type/*" indicating all subtypes of that type.
 
