@@ -1,13 +1,11 @@
 package LWP::UserAgent;
 
-# $Id: UserAgent.pm,v 2.31 2004/04/10 11:26:14 gisle Exp $
-
 use strict;
 use vars qw(@ISA $VERSION);
 
 require LWP::MemberMixin;
 @ISA = qw(LWP::MemberMixin);
-$VERSION = sprintf("%d.%03d", q$Revision: 2.31 $ =~ /(\d+)\.(\d+)/);
+$VERSION = "5.810";
 
 use HTTP::Request ();
 use HTTP::Response ();
@@ -32,6 +30,10 @@ if ($ENV{PERL_LWP_USE_HTTP_10}) {
 
 sub new
 {
+    # Check for common user mistake
+    Carp::croak("Options to LWP::UserAgent should be key/value pairs, not hash reference") 
+        if ref($_[1]) eq 'HASH'; 
+
     my($class, %cnf) = @_;
     LWP::Debug::trace('()');
 
@@ -80,12 +82,13 @@ sub new
 
     my $self = bless {
 		      from         => $from,
+		      def_headers  => undef,
 		      timeout      => $timeout,
 		      use_eval     => $use_eval,
 		      parse_head   => $parse_head,
 		      max_size     => $max_size,
 		      max_redirect => $max_redirect,
-		      proxy        => undef,
+		      proxy        => {},
 		      no_proxy     => [],
                       protocols_allowed     => $protocols_allowed,
                       protocols_forbidden   => $protocols_forbidden,
@@ -208,6 +211,7 @@ EOT
       @{$self}{qw(timeout cookie_jar use_eval parse_head max_size)};
 
     my $response;
+    $self->progress("begin");
     if ($use_eval) {
 	# we eval, and turn dies into responses below
 	eval {
@@ -230,6 +234,8 @@ EOT
     $response->request($request);  # record request for reference
     $cookie_jar->extract_cookies($response) if $cookie_jar;
     $response->header("Client-Date" => HTTP::Date::time2str(time));
+
+    $self->progress("end", $response);
     return $response;
 }
 
@@ -240,8 +246,8 @@ sub prepare_request
     $self->_request_sanity_check($request);
 
     # Extract fields that will be used below
-    my ($agent, $from, $cookie_jar, $max_size) =
-      @{$self}{qw(agent from cookie_jar max_size)};
+    my ($agent, $from, $cookie_jar, $max_size, $def_headers) =
+      @{$self}{qw(agent from cookie_jar max_size def_headers)};
 
     # Set User-Agent and From headers if they are defined
     $request->init_header('User-Agent' => $agent) if $agent;
@@ -253,6 +259,12 @@ sub prepare_request
     }
     $cookie_jar->add_cookie_header($request) if $cookie_jar;
 
+    if ($def_headers) {
+	for my $h ($def_headers->header_field_names) {
+	    $request->init_header($h => [$def_headers->header($h)]);
+	}
+    }
+
     return($request);
 }
 
@@ -416,7 +428,7 @@ sub get {
 sub post {
     require HTTP::Request::Common;
     my($self, @parameters) = @_;
-    my @suff = $self->_process_colonic_headers(\@parameters,2);
+    my @suff = $self->_process_colonic_headers(\@parameters, (ref($parameters[1]) ? 2 : 1));
     return $self->request( HTTP::Request::Common::POST( @parameters ), @suff );
 }
 
@@ -478,6 +490,11 @@ sub _process_colonic_headers {
     return $arg;
 }
 
+sub progress {
+    my($self, $status, $response) = @_;
+    # subclasses might override this
+}
+
 
 #
 # This whole allow/forbid thing is based on man 1 at's way of doing things.
@@ -599,6 +616,20 @@ sub cookie_jar {
     $old;
 }
 
+sub default_headers {
+    my $self = shift;
+    my $old = $self->{def_headers} ||= HTTP::Headers->new;
+    if (@_) {
+	$self->{def_headers} = shift;
+    }
+    return $old;
+}
+
+sub default_header {
+    my $self = shift;
+    return $self->default_headers->header(@_);
+}
+
 
 sub conn_cache {
     my $self = shift;
@@ -850,6 +881,7 @@ The following options correspond to attribute methods described below:
    from                    undef
    conn_cache              undef
    cookie_jar              undef
+   default_headers         HTTP::Headers->new
    max_size                undef
    max_redirect            7
    parse_head              1
@@ -922,7 +954,8 @@ the requests.  Example:
 
   $ua->from('gaas@cpan.org');
 
-The default is to not send a "From" header.
+The default is to not send a "From" header.  See the default_headers()
+method for the more general interface that allow any header to be defaulted.
 
 =item $ua->cookie_jar
 
@@ -950,6 +983,25 @@ is really just a shortcut for:
   require HTTP::Cookies;
   $ua->cookie_jar(HTTP::Cookies->new(file => "$ENV{HOME}/.cookies.txt"));
 
+=item $ua->default_headers
+
+=item $ua->default_headers( $headers_obj )
+
+Get/set the headers object that will provide default header values for
+any requests sent.  By default this will be an empty C<HTTP::Headers>
+object.  Example:
+
+  $ua->default_headers->push_header('Accept-Language' => "no, en");
+
+=item $ua->default_header( $field )
+
+=item $ua->default_header( $field => $value )
+
+This is just a short-cut for $ua->default_headers->header( $field =>
+$value ). Example:
+
+  $ua->default_header('Accept-Language' => "no, en");
+
 =item $ua->conn_cache
 
 =item $ua->conn_cache( $cache_obj )
@@ -962,6 +1014,11 @@ for details.
 Set the user name and password to be used for a realm.  It is often more
 useful to specialize the get_basic_credentials() method instead.
 
+The $netloc a string of the form "<host>:<port>".  The username and
+password will only be passed to this server.  Example:
+
+  $ua->credenticals("www.example.com:80", "Some Realm", "foo", "secret");
+
 =item $ua->max_size
 
 =item $ua->max_size( $bytes )
@@ -1168,6 +1225,12 @@ Otherwise it works like the get() method described above.
 
 =item $ua->post( $url, \%form, $field_name => $value, ... )
 
+=item $ua->post( $url, $field_name => $value,... Content => \%form )
+
+=item $ua->post( $url, $field_name => $value,... Content => \@form )
+
+=item $ua->post( $url, $field_name => $value,... Content => $content )
+
 This method will dispatch a C<POST> request on the given $url, with
 %form or @form providing the key/value pairs for the fill-in form
 content. Additional headers and content options are the same as for
@@ -1297,6 +1360,15 @@ with this library.
 The base implementation simply checks a set of pre-stored member
 variables, set up with the credentials() method.
 
+=item $ua->progress( $status, $response )
+
+This is called frequently as the response is received regardless of
+how the content is processed.  The method is called with $status
+"begin" at the start of processing the request and with $state "end"
+before the request method returns.  In between these $status will be
+the fraction of the response currently received or the string "tick"
+if the fraction can't be calculated.
+
 =back
 
 =head1 SEE ALSO
@@ -1314,7 +1386,7 @@ specialized user agents based on C<LWP::UserAgent>.
 
 =head1 COPYRIGHT
 
-Copyright 1995-2004 Gisle Aas.
+Copyright 1995-2008 Gisle Aas.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
